--[[ Roster module to Handle the Raid Roster    ]]
--[[ tab widths set to 4 for optimal formatting ]]

local _, TriageTable = ...; 

local Triage = TriageTable.Triage
Triage.Dialog = Triage:NewModule("Dialog", "AceEvent-3.0", "AceBucket-3.0")
local Dialog = Triage.Dialog

local L = LibStub("AceLocale-3.0"):GetLocale("Triage");


-- The various state tables.
Dialog.heal = { }
Dialog.heal.unassigned = { }
Dialog.heal.assigned = { }
Dialog.dps = { }
Dialog.dps.unassigned = { }
Dialog.dps.assigned = { }
Dialog.tank = { }
Dialog.tank.unassigned = { }
Dialog.tank.assigned = { }
Dialog.other = { }
Dialog.other.unassigned = { }
Dialog.other.assigned = { }


function Dialog:Debug( str, ... )
	Triage:Debug("|c933f9fffDialog|r - "..str , ... )
end



function Dialog:OnInitialize() 
	self:Debug( "OnInitialize" )
end



function Dialog:OnEnable()
	self:Debug( "OnEnable" )

	if not self.frame then
		self:CreateDialog()
	end

	self:RegisterMessage( "Triage_RosterUpdated", "RosterUpdated" )

	if oRA3 then
		self:Debug( "Registering for oRA3 Tanks" )
		oRA3.RegisterCallback( self, "OnTanksUpdated", "ORA3TanksUpdated" )
		self:ORA3TanksUpdated( "OnTanksUpdated", oRA3:GetSortedTanks() )
	end

	self:Debug( "OnEnable complete" )
end



function Dialog:OnLoad()
	self:Debug( "OnLoad" )
end



function Dialog:CreateDialog()
	self:Debug( "CreateDialog" )

	-- Sizes/counts of various elements
	self.available_size = 25
	self.group_count = 8
	self.group_size = 5

	-- Localize the XML items
	_G["TriageDialogAvailableLabel"]:SetText(L["Unassigned"])
	for i = 1, self.available_size do
		local key = ( "TriageDialogAvailableSlot%dLabel" ):format( i )
		local value = "Empty"
		_G[key]:SetText( L[value] )
	end

	for i = 1, self.group_count do
		local key = ( "TriageDialogAssignmentGroup%dLabel" ):format( i )
		local value = ( "Assignment %d" ):format( i )
		_G[key]:SetText( L[value] )
		for k = 1, self.group_size do
			key = ( "TriageDialogAssignmentGroup%dSlot%dLabel" ):format( i, k )
			value = "Empty"
			_G[key]:SetText( L[value] )
		end
	end


	-- Create assignment groups tables
	for i = 1, self.group_count do
		self.heal.assigned[ i ] = { }
		self.dps.assigned[ i ] = { }
		self.tank.assigned[ i ] = { }
		self.other.assigned[ i ] = { }
	end

	-- Create the buttons
	local frame_level = TriageDialog:GetFrameLevel()
	self.available_buttons = { }
	for i = 1, self.available_size do
		local name = ( "TriagePlayerButton%d" ):format( i )
		local button = CreateFrame( "Button", name, TriageDialog, 
								"TriageButtonTemplate" )
		button:ClearAllPoints()
		button:SetFrameLevel( frame_level + 5 )
		button:SetMovable( true )
		button:RegisterForDrag( "LeftButton" )
		button:EnableMouse( true )
		button:SetClampedToScreen( true )
		button:Hide()
		self.available_buttons[ i ] = button
		self.next_available_button = i
	end

	self.frame = TriageDialog
	self:Debug( "CreateDialog complete" )
end



function Dialog:RosterUpdated( event )
	self:Debug( "RosterUpdated" )
	local raid_size, raid_roster, waiting_roster, class, role =
		Triage.Roster:GetRaidRoster()

		
end



function Dialog:ORA3TanksUpdated( event, tanks )
	self.ora3_tanks = tanks
	local tank_list = "oRA3 Tanks:"
	for i = 1, #tanks do
		tank_list = tank_list.." "..tanks[ i ]
	end
	Dialog:Debug( tank_list )
end



-- Deprecated, kept for now for reference.  TODO: delete
function Dialog:CreateMainDialog()
	self:Debug( "CreateMainDialog" )

	local font = media and media:Fetch("font", self.db.profile.font) or STANDARD_TEXT_FONT

	local frame = CreateFrame( "Frame", "TriageDialog", UIParent )

	frame:SetWidth( 480 )
	frame:SetHeight( 600 )

	frame:SetFrameStrata( "DIALOG")
	frame:SetToplevel( true )
	frame:EnableMouse( true )
	frame:SetClampedToScreen( true )

	frame:SetMovable( true )
	frame:SetPoint( "TOP", UIParent, "TOP", 0, -50 )

	frame:SetBackdrop{
		bgFile="Interface\\DialogFrame\\UI-DialogBox-Background" ,
		edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border",
		tile = true,
		insets = {left = 11, right = 12, top = 12, bottom = 11},
		tileSize = 32, edgeSize = 32,
	}

	frame.texture = frame:CreateTexture( nil, "BORDER" )
	frame.texture:SetPoint( "TOPLEFT", frame, "TOPLEFT", 4, -4 )
	frame.texture:SetPoint( "BOTTOMRIGHT", frame, "BOTTOMRIGHT", -4, 4 )
	frame.texture:SetBlendMode( "ADD" )
	frame.texture:SetGradientAlpha( "VERTICAL", .1, .1, .1, 0, .2, .2, .2, 0.5 )
	frame:EnableMouse( true )
	
	local titleRegion = frame:CreateTitleRegion()
	titleRegion:SetPoint( "TOP", frame, "TOP", 0, 22 )
	titleRegion:SetPoint( "LEFT", frame, "TOP", -50, 0 )
	titleRegion:SetPoint( "RIGHT", frame, "TOP", 50, 0 )
	titleRegion:SetPoint( "BOTTOM", frame, "TOP", 0, -16 )

	local header = frame:CreateTexture( nil, "ARTWORK" )
	header:SetTexture( "Interface\\DialogFrame\\UI-DialogBox-Header" )
	header:SetWidth( 256 )
	header:SetHeight( 64 )
	header:SetPoint( "TOP", 0, 12 )

	local title = frame:CreateFontString( "ARTWORK" )
	title:SetFontObject( "GameFontNormal" )
	title:SetPoint( "TOP", header, "TOP", 0, -14 )
	title:SetText( L["Triage"] )

	local closeButton = CreateFrame( "Button", "CloseDialogButton",
		frame, "UIPanelCloseButton")
	closeButton:SetPoint( "TOPRIGHT", 0, 0)
	closeButton:SetScript( "OnClick", function( self ) Dialog:HideDialog() end )

	frame:SetScript( "OnShow", function() PlaySound( "igMainMenuOption" ) end )
	frame:SetScript( "OnHide", function() PlaySound( "gsTitleOptionExit" ) end )

	frame:Hide()
	tinsert( UISpecialFrames,"TriageDialog" );
	return frame
end



function Dialog:CreateAvailable( parent )
	self:Debug( "CreateAvailable" )

	local frame = CreateFrame( "Frame", "TriageAvailable", parent )

	frame:SetWidth( 100 )
	frame:SetHeight( 261 )

	frame:SetPoint( "TOPLEFT", parent, "TOPLEFT", 14, -45 )

	frame:SetBackdrop{
		bgFile="Interface\\DialogFrame\\UI-DialogBox-Background" ,
--		edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border",
		tile = true,
		insets = {left = 1, right = 1, top = 1, bottom = 1},
		tileSize = 32, edgeSize = 32,
	}

	frame.texture = frame:CreateTexture( nil, "BORDER" )
	frame.texture:SetPoint( "TOPLEFT", frame, "TOPLEFT", 4, -4 )
	frame.texture:SetPoint( "BOTTOMRIGHT", frame, "BOTTOMRIGHT", -4, 4 )
	frame.texture:SetBlendMode( "DISABLE" )
--	frame.texture:SetGradientAlpha( "VERTICAL", .1, .1, .1, 0, .2, .2, .2, 0.5 )
	frame:EnableMouse( true )

	frame.slots = { }
	for index, slotname in ipairs( self.available ) do
		local slot = self:CreateAvailableSlot( frame, index, slotname )
		frame.slots[ index ] = slot
	end

	parent.availableFrame = frame
end




function Dialog:Dialog()
	self:Debug( "Dialog" )
	if self.frame then
		if self.frame:IsShown() then
			self:HideDialog()
		else
			self:ShowDialog()
		end
	end
end



function Dialog:ShowDialog()
	self:Debug( "ShowDialog" )
	if Triage.inCombat then
		self:Debug( "  in combat, refusing to display" );
		return
	end
	if self.frame then
		self.frame:Show()
	else 
		 TriageDialog:Show()
	end
	
end



function Dialog:HideDialog()
	self:Debug( "HideDialog" )
	if self.frame then
		self.frame:Hide()
	end
end



function Dialog:PlayerButtonOnLoad( button )
	self:Debug( "PlayerButtonOnLoad: "..button:GetName() )
end



function Dialog:PlayerButtonOnClick( button )
	self:Debug( "PlayerButtonOnClick: "..button:GetName() )
end



function Dialog:PlayerButtonOnDragStart( button )
	self:Debug( "PlayerButtonOnDragStart: "..button:GetName() )
end




function Dialog:PlayerButtonOnDragStop( button )
	self:Debug( "PlayerButtonOnDragStop: "..button:GetName() )
end
